/*
Blink using Timer interrupts
from Linux Format 154
based on code and ideas from:
arduino playground - www.arduino.cc
Michael Smith <michael@hurts.ca>
Atmel datasheets - http://www.atmel.com/
*/


/* LISTING 4
* In this version we add another interrupt for Compare register B  
* We set this value just short of 65250. We use the ISR_ALIAS() macro to 
* point it at the same interrupt routine, to toggle the LED. The effect is a sort of
* inverted heartbeat blink.
*/


void setup() {

DDRB |= _BV(PB5);

cli(); // disable interrupts - safer when fiddling with interrupt registers

TCNT1=0x0000; // reset counter to 0 at start
TCCR1A= B00000000; // turn off PWM
TCCR1B= B00001100; // set CTC and prescalar to /256
TIMSK1 |= _BV(OCIE1A) | _BV(OCIE1B) ; // enable timer compare A and B interrupt

/// NB - set the values for OCR1A register after changing TCCR1, or they get reset to 0!
OCR1A = 62500; //set the comparator A to 62500
OCR1B = 60000; // set the comparator B to 20000
sei(); // re-enable interrupts
PORTB |= _BV(PB5);//start with LED on
// start serial access - this is to get around a bug on some
// systems which don't initialise the data segment properly
Serial.begin(9600);
};

void loop () {
///your useful code here
};


ISR(TIMER1_COMPA_vect) {
//toggle the value
PORTB ^= _BV(PB5);
// this works by XORing the bit with 1, which turns 1 to 0 and 0 to 1
};

ISR_ALIAS(TIMER1_COMPB_vect,TIMER1_COMPA_vect );
//set the same interrupt routine for both interrupts
